/* wrap.h     Simple custom wrappers for Portland example
 *
 * Copyright (c) 2014 Psellos   http://psellos.com
 * Licensed under the MIT license:
 *     http://www.opensource.org/licenses/mit-license.php
 */
# import "caml/mlvalues.h"

/* An OCaml value wrapped up for access from ObjC.
 */
@interface WrapOCaml : NSObject
@property (nonatomic, readonly) value contents;
@end

/* A protocol for delegation of view controller behavior.
 */
@protocol ViewControllerDelegate
- (void) viewController: (UIViewController *) vc
         viewWillAppear: (BOOL) animated;
- (void) viewController: (UIViewController *) vc
         viewWillDisappear: (BOOL) animated;
- (BOOL) viewControllerShouldAutorotate: (UIViewController *) vc;
@end

/* Wrapped version of PortlandAppDelegate.t
 */
@interface PortlandAppDelegate : WrapOCaml <UIApplicationDelegate>
@end

/* Wrapped version of PortlandViewControllerD.t
 */
@interface PortlandViewControllerD : WrapOCaml <ViewControllerDelegate>
@property (nonatomic, strong) IBOutlet UILabel *label;
- (void) timerTick: (NSTimer *) aTimer;
@end

/* PortlandViewController just passes methods along to a delegate.
 */
@interface PortlandViewController : UIViewController
@property (nonatomic, strong) IBOutlet id<ViewControllerDelegate> delegate;
@end
